# Common actions for model.graphics, test.graphics, and clean.graphics

getDevice <- function(device) {
  dev <- list()
  if (is.character(device)) {
    # dev$call <- get(device)
    dev$name <- device
  }
  else {
    # dev$call <- device
    dev$name <- deparse(substitute(device, env=parent.frame()))
  }
  if (charmatch(dev$name, "postscript", nomatch=FALSE))
    dev$fns <- postscript.fns
  else if (charmatch(dev$name, "x11", nomatch=FALSE))
    dev$fns <- x11.fns
  else if (charmatch(dev$name, "pdf", nomatch=FALSE))
    dev$fns <- pdf.fns
  else
    stop(paste("QC for the", dev$name, "device has not yet been implemented"))
  dev
}

getFuns <- function(funs, package) {
  # Must specify exactly one of funs or package
  if (is.null(funs)) {
    if (is.null(package))
      stop("Must specify one of `funs' or `package'")
    else {
      if (!is.character(package))
        package <- deparse(substitute(package, env=parent.frame()))
      # We want to test all example code for a package
      # Omit names beginning with %, [, ...
      # or containing <-
      funs <- ls(paste("package:", package, sep=""), all.names=FALSE,
                 pattern="^[[:alpha:]]([[:alpha:]]|[.])+$")
      packages <- package
    } 
  } else {
    # funs must be character
    if (!is.character(funs))
      stop("`funs' must be a character vector")
    packages <- .packages()
  }
  # Pare the funs list down to remove functions without example
  # code and functions with identical help files
  nfuns <- length(funs)
  index <- rep(TRUE, nfuns)
  filesofar <- rep("", nfuns)
  for (i in 1:nfuns) {
    examplefile <- index.search(funs[i], .find.package(packages),
                                "AnIndex", "R-ex")
    filesofar[i] <- examplefile
    if (charmatch(examplefile, "", nomatch=FALSE) ||
        examplefile %in% filesofar[-i])
      index[i] <- FALSE
  }
  funs <- funs[index]
  funs
}
