"model.graphics" <-
function(funs=NULL,
         package=NULL,
         names=NULL,
         width=600,
         height=600,
         device=postscript,
         format="pbm",
         model.loc=".",
         verbose=FALSE,
         reset.rng=TRUE,
         # additional arguments to the device
         ...) {
  dev <- getDevice(device)
  # format should be character
  format <- as.character(format)
  # width and height must be integer
  width <- as.integer(width)
  height <- as.integer(height)
  # model.loc must be character
  model.loc <- as.character(model.loc)
  funs <- getFuns(funs, package)
  # names must be NULL or same length as funs
  if (!is.null(names)) {
    if (length(names) != length(funs))
      stop("`names' must be the same length as `funs'")
  }
  # If the model.loc directory doesn't exist, create it
  if (!file.exists(model.loc))
    if (!file.create(model.loc))
      stop(paste("Unable to create directory", model.loc))
  count <- 1
  for (i in funs) {
    if (verbose)
      cat("model.graphics:", i, "\n");
    # Generate the model output
    filebasename <- paste(if (is.null(names)) i else names[count],
                          "-", dev$name, "-",
                          width, "x", height, sep="")
    filefullname <- file.path(model.loc, filebasename)
    dev$fns$open(filefullname, ".save.", width, height, ...)
    # Shut up example()'s warnings about "help file, but no examples"
    options(warn=-1)
    # Reset random number generator so that randomly-generated data
    # do not show up as differences
    if (reset.rng)
      set.seed(7654, "Wichmann-Hill")
    # Need to do something like rm(list = ls(all.names = TRUE))
    # to tidy up the environment between runs of example()
    # Wrap this in a try so that any "stop()"s in example code
    # do not chuck us out
    # Can't use example(i) because example() always does a substitute(topic)
    try(eval(call("example", i, echo=FALSE)))
    options(warn=0)
    dev$fns$close(filefullname, ...)
    # Convert to bitmap format
    dev$fns$convert(model.loc, filebasename, ".save.",
                       format, width, height, ...)
    count <- count + 1
  }
}
